# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.18](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.17...aoe2rec-py-v0.1.18) - 2025-12-14

### Other

- updated the following local packages: aoe2rec

## [0.1.17](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.16...aoe2rec-py-v0.1.17) - 2025-12-13

### Other

- updated the following local packages: aoe2rec

## [0.1.16](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.15...aoe2rec-py-v0.1.16) - 2025-12-12

### Other

- updated the following local packages: aoe2rec

## [0.1.15](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.14...aoe2rec-py-v0.1.15) - 2025-12-12

### Other

- updated the following local packages: aoe2rec

## [0.1.14](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.13...aoe2rec-py-v0.1.14) - 2025-12-12

### Other

- Fix linting errors and update depedencies

## [0.1.13](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.12...aoe2rec-py-v0.1.13) - 2025-08-15

### Other

- updated the following local packages: aoe2rec

## [0.1.12](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.11...aoe2rec-py-v0.1.12) - 2025-08-14

### Other

- updated the following local packages: aoe2rec

## [0.1.11](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.10...aoe2rec-py-v0.1.11) - 2025-08-13

### Other

- updated the following local packages: aoe2rec

## [0.1.10](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.9...aoe2rec-py-v0.1.10) - 2025-04-11

### Other

- updated the following local packages: aoe2rec

## [0.1.9](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.8...aoe2rec-py-v0.1.9) - 2025-03-30

### Other

- Update pyo3 to 0.24

## [0.1.8](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.7...aoe2rec-py-v0.1.8) - 2025-02-23

### Other

- updated the following local packages: aoe2rec

## [0.1.7](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.6...aoe2rec-py-v0.1.7) - 2025-02-22

### Other

- updated the following local packages: aoe2rec

## [0.1.6](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.5...aoe2rec-py-v0.1.6) - 2025-02-05

### Other

- updated the following local packages: aoe2rec

## [0.1.5](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.4...aoe2rec-py-v0.1.5) - 2025-01-14

### Added

- Add winner calculation

### Fixed

- Chats and duration should not be class variables
- Turn aoe2rec-py into a package

### Other

- Updated pyproject.toml to include git repo

## [0.1.4](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.3...aoe2rec-py-v0.1.4) - 2025-01-13

### Fixed

- Increase minimum version requirement to 3.9
- Try and support python versions older than 3.12

## [0.1.3](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.2...aoe2rec-py-v0.1.3) - 2025-01-13

### Added

- Calculate the eAPM

## [0.1.2](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.1...aoe2rec-py-v0.1.2) - 2025-01-12

### Added

- Implement get_diplomacy

## [0.1.1](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.0...aoe2rec-py-v0.1.1) - 2025-01-12

### Added

- Implement get_settings method

## [0.1.0](https://github.com/aoe2ct/aoe2rec/releases/tag/aoe2rec-py-v0.1.0) - 2025-01-12

### Other

- Add first draft of python module implementation
